My name is [Arash](http://kamangir.net/); I mix [ai](https://github.com/kamangir/roofAI), [cloud](https://github.com/kamangir/hubble), and [mathematics](https://github.com/kamangir/giza) into minimal forms that seek survival.

|   |   |   |
| --- | --- | --- |
| 🌐 [`blue-geo`](https://github.com/kamangir/blue-geo) [![image](https://github.com/kamangir/assets/raw/main/nbs/ukraine-timemap/QGIS.png?raw=true)](https://github.com/kamangir/blue-geo) AI for precise geospatial data analysis and visualization.  [![PyPI version](https://img.shields.io/pypi/v/blue_geo.svg)](https://pypi.org/project/blue_geo/) | 🔭 [`hubblescope`](https://github.com/kamangir/hubble) [![image](https://github.com/kamangir/hubble/raw/main/assets/hst/u4ge0106r_c0m.gif)](https://github.com/kamangir/hubble) tools to access and process Hubble Space Telescope imagery and other datasets on AWS Open Data Registry.  [![PyPI version](https://img.shields.io/pypi/v/hubblescope.svg)](https://pypi.org/project/hubblescope/) | 🌀 [`blue-options`](https://github.com/kamangir/blue-options) [![image](https://github.com/kamangir/assets/raw/main/blue-plugin/marquee.png?raw=true)](https://github.com/kamangir/blue-options) an options for Bash.  [![PyPI version](https://img.shields.io/pypi/v/blue_options.svg)](https://pypi.org/project/blue_options/) |
| 🌈 [`vancouver-watching`](https://github.com/kamangir/vancouver-watching) [![image](https://user-images.githubusercontent.com/1007567/196573547-b1c71b3b-7fac-4d2c-bba0-a87b063830da.png)](https://github.com/kamangir/vancouver-watching) Vancouver Watching with AI.  [![PyPI version](https://img.shields.io/pypi/v/vancouver_watching.svg)](https://pypi.org/project/vancouver_watching/) | 🏛️ [`roofAI`](https://github.com/kamangir/roofAI) [![image](https://github.com/kamangir/assets/blob/main/2023-10-28-16-28-36-88493-predict.gif?raw=true)](https://github.com/kamangir/roofAI) everything AI about roofs.  [![PyPI version](https://img.shields.io/pypi/v/roofAI.svg)](https://pypi.org/project/roofAI/) | 🛠️ [`openai-commands`](https://github.com/kamangir/openai-commands) [![image](https://github.com/kamangir/openai-commands/raw/main/assets/carrot.png)](https://github.com/kamangir/openai-commands) a command interface to the OpenAI API.  [![PyPI version](https://img.shields.io/pypi/v/openai_commands.svg)](https://pypi.org/project/openai_commands/) |
| 📜 [`notebooks-and-scripts`](https://github.com/kamangir/notebooks-and-scripts) [![image](https://github.com/kamangir/assets/raw/main/nbs/3x4.jpg?raw=true)](https://github.com/kamangir/notebooks-and-scripts) notebooks and scripts for ai experiments and aws batch jobs.  [![PyPI version](https://img.shields.io/pypi/v/notebooks_and_scripts.svg)](https://pypi.org/project/notebooks_and_scripts/) | 🔻 [`gizai`](https://github.com/kamangir/giza) [![image](https://github.com/kamangir/giza/raw/main/assets/giza.png)](https://github.com/kamangir/giza) a recipe for AI languages.  [![PyPI version](https://img.shields.io/pypi/v/gizai.svg)](https://pypi.org/project/gizai/) | 🟦 [`blue-stability`](https://github.com/kamangir/blue-stability) [![image](https://github.com/kamangir/AI-ART/raw/main/blue-stability/blue_stability.gif)](https://github.com/kamangir/blue-stability) a command interface to stability.ai.  [![PyPI version](https://img.shields.io/pypi/v/blue_stability.svg)](https://pypi.org/project/blue_stability/) |
| 🎨 [`articraft`](https://github.com/kamangir/aiart) [![image](https://github.com/kamangir/openai-commands/raw/main/assets/DALL-E.png?raw=1)](https://github.com/kamangir/aiart) tools for ai artists.  [![PyPI version](https://img.shields.io/pypi/v/articraft.svg)](https://pypi.org/project/articraft/) | 🪄 [`abcli`](https://github.com/kamangir/awesome-bash-cli) [![image](https://github.com/kamangir/awesome-bash-cli/raw/main/assets/marquee.png)](https://github.com/kamangir/awesome-bash-cli) a language to speak AI.  [![PyPI version](https://img.shields.io/pypi/v/abcli.svg)](https://pypi.org/project/abcli/) | 🌀 [`blue-plugin`](https://github.com/kamangir/blue-plugin) [![image](https://github.com/kamangir/assets/raw/main/blue-plugin/marquee.png?raw=true)](https://github.com/kamangir/blue-plugin) a git template for an awesome-bash-cli plugin.  [![PyPI version](https://img.shields.io/pypi/v/blue_plugin.svg)](https://pypi.org/project/blue_plugin/) |
| 🌀 [`ferfereh`](https://github.com/kamangir/ferfereh) [![image](https://user-images.githubusercontent.com/1007567/221448494-d57e08c1-625b-499e-a576-81894f112d6a.jpg)](https://github.com/kamangir/ferfereh) 3d-printed graffiti.  [![PyPI version](https://img.shields.io/pypi/v/ferfereh.svg)](https://pypi.org/project/ferfereh/) | [`Kanata`](https://github.com/kamangir/Kanata) [![image](https://kamangir-public.s3.ca-central-1.amazonaws.com/Canadians_v11.gif)](https://github.com/kamangir/Kanata) a multi-screen video feed that is comprised of a matrix of animated faces that slide to the right.  | [`dec82`](https://github.com/kamangir/dec82) [![image](https://github.com/kamangir/blue-bracket/raw/main/images/dec82-6.jpg)](https://github.com/kamangir/dec82) A wearable Raspberry Pi + Grove / Qwiic + Camera.  |
| [`blue-rvr`](https://github.com/kamangir/blue-rvr) [![image](https://github.com/kamangir/blue-rvr/raw/master/abcli/assets/marquee.jpeg)](https://github.com/kamangir/blue-rvr) a bash cli for Sphero RVR SDK - runs deep learning vision models on a Raspberry Pi using Python and TensorFlow.  | [`blue-bracket`](https://github.com/kamangir/blue-bracket) [![image](https://github.com/kamangir/blue-bracket/raw/main/images/marquee.jpg)](https://github.com/kamangir/blue-bracket) a parametric 3d-printed bracket to build hardware for machine vision & ai on raspberry pi and jetson nano on the edge.  | [`blue-sbc`](https://github.com/kamangir/blue-sbc) [![image](https://github.com/kamangir/blue-bracket/raw/main/images/blue3-1.jpg)](https://github.com/kamangir/blue-sbc) python + bash bootstrap for edge computing on single board computers.  |

---

to use on [AWS SageMaker](https://aws.amazon.com/sagemaker/) replace `<plugin-name>` with "kamangir" and follow [these instructions](https://github.com/kamangir/notebooks-and-scripts/blob/main/SageMaker.md).

[![pylint](https://github.com/kamangir/kamangir/actions/workflows/pylint.yml/badge.svg)](https://github.com/kamangir/kamangir/actions/workflows/pylint.yml) [![pytest](https://github.com/kamangir/kamangir/actions/workflows/pytest.yml/badge.svg)](https://github.com/kamangir/kamangir/actions/workflows/pytest.yml) [![bashtest](https://github.com/kamangir/kamangir/actions/workflows/bashtest.yml/badge.svg)](https://github.com/kamangir/kamangir/actions/workflows/bashtest.yml) [![PyPI version](https://img.shields.io/pypi/v/kamangir.svg)](https://pypi.org/project/kamangir/)

built by 🪄 [`abcli-9.257.1-current`](https://github.com/kamangir/awesome-bash-cli), based on 📜 [`kamangir-3.134.1`](https://github.com/kamangir/kamangir).
